SystemOrganization addCategory: #ConfigurationOfSqSync!

Object subclass: #ConfigurationOfSqSync
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfSqSync'!

!ConfigurationOfSqSync class methodsFor: 'development support' stamp: 'DaleHenrichs 12/17/2010 10:23'!
DevelopmentSupport

"See the methods in the 'development support' category on the class-side of MetacelloBaseConfiguration. Decide what development support methods you would like to use and copy them the the class-side of your configuration."
	<apiDocumentation>
! !

!ConfigurationOfSqSync class methodsFor: 'private' stamp: 'DaleHenrichs 11/2/2010 16:51'!
baseConfigurationClassIfAbsent: aBlock

	^Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			self ensureMetacelloBaseConfiguration.
			Smalltalk at: #MetacelloBaseConfiguration ifAbsent: aBlock ].
! !

!ConfigurationOfSqSync class methodsFor: 'private' stamp: 'DaleHenrichs 12/6/2010 13:34'!
ensureMetacello

	(self baseConfigurationClassIfAbsent: []) ensureMetacello! !

!ConfigurationOfSqSync class methodsFor: 'private' stamp: 'DaleHenrichs 11/4/2010 10:23'!
ensureMetacelloBaseConfiguration

	Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			| repository version |
			repository := MCHttpRepository location: 'http://seaside.gemstone.com/ss/metacello' user: '' password: ''.
			repository
				versionReaderForFileNamed: 'Metacello-Base-DaleHenrichs.2.mcz'
				do: [ :reader | 
					version := reader version.
					version load.
					version workingCopy repositoryGroup addRepository: repository ] ]! !

!ConfigurationOfSqSync class methodsFor: 'metacello tool support' stamp: 'DaleHenrichs 11/2/2010 14:58'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfSqSync class methodsFor: 'loading' stamp: 'DaleHenrichs 11/29/2010 15:00'!
load
	"Load the #stable version defined for this platform. The #stable version is the version that is recommended to be used on this platform."

	"self load"

	<apiDocumentation>
	^(self project version: #stable) load! !

!ConfigurationOfSqSync class methodsFor: 'loading' stamp: 'DaleHenrichs 11/29/2010 15:00'!
loadBleedingEdge
	"Load the latest versions of the mcz files defined for this project. It is not likely that the #bleedingEdge has been tested."

	"self loadBleedingEdge"

	<apiDocumentation>
	^(self project version: #bleedingEdge) load! !

!ConfigurationOfSqSync class methodsFor: 'loading' stamp: 'DaleHenrichs 11/29/2010 15:00'!
loadDevelopment
	"Load the #development version defined for this platform. The #development version will change over time and is not expected to be stable."

	"self loadDevelopment"

	<apiDocumentation>
	^(self project version: #development) load! !

!ConfigurationOfSqSync class methodsFor: 'accessing' stamp: 'dkh 10/13/2009 10:36'!
project

	^self new project! !

!ConfigurationOfSqSync class methodsFor: 'development support' stamp: 'DaleHenrichs 1/13/2011 15:37'!
validate
	"Check the configuration for Errors, Critical Warnings, and Warnings (see class comment for MetacelloMCVersionValidator for more information). 
	Errors identify specification issues that will result in unexpected behaviour when you load the configuration. 
	Critical Warnings identify specification issues that may result in unexpected behavior when you load the configuration.
	Warnings identify specification issues that are technically correct, but are worth take a look at."

	"self validate"

	<apiDocumentation>
	self ensureMetacello.
	^ ((Smalltalk at: #MetacelloToolBox) validateConfiguration: self debug: #() recurse: false) explore! !

!ConfigurationOfSqSync methodsFor: 'baselines' stamp: 'mt 10/6/2010 17:15:48.397'!
baseline100: spec 
	<version: '1.0-baseline'>
        
	spec for: #common do: [
      	spec blessing: #baseline.
      	spec repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/SqSync'.

		spec project: 'Signals' with: [
			spec
				className: 'ConfigurationOfSignals';
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/MetacelloRepository'].

		spec project: 'Widgets' with: [
			spec
				className: 'ConfigurationOfWidgets';
				repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/MetacelloRepository'].
		
		spec package: 'MethodWrappers' with: [
			spec repository: 'http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/SwaUtilities'].

		spec package: 'ProcessSpecific' with: [
			spec repository: 'http://www.squeaksource.com/ProcessLocalStorage'].

		spec
			package: 'SqSync' with: [spec requires: #('MethodWrappers' 'Signals' 'ProcessSpecific')];
			package: 'SY-AddressBook' with: [spec requires: #('Widgets' 'SqSync')];
			package: 'SY-ProjectAnalyzation'	with: [spec requires: #('SqSync')].
		spec
			group: 'default' with: #('SqSync');
			group: 'full' with: #('SqSync' 'SY-AddressBook' 'SY-ProjectAnalyzation') ].! !

!ConfigurationOfSqSync methodsFor: 'accessing' stamp: 'DaleHenrichs 11/5/2010 13:54'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		(self class baseConfigurationClassIfAbsent: []) ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfSqSync methodsFor: 'symbolic versions' stamp: 'mt 2/5/2011 17:51:43.547'!
stable: spec 
	<symbolicVersion: #stable>
	
	spec for: #'squeak4.1.x' version: '1.0'.
	spec for: #'squeak4.2.x' version: '1.0'.! !

!ConfigurationOfSqSync methodsFor: 'versions' stamp: 'mt 2/5/2011 17:42:15.77'!
version100: spec

	<version: '1.0' imports: #('1.0-baseline')>
	
	spec for: #common do: [
		spec blessing: #release.
		
		spec
			package: 'SqSync' with: 'SqSync-mt.127';
			package: 'SY-AddressBook' with: 'SY-AddressBook-mt.2';
			package: 'SY-ProjectAnalyzation' with: 'SY-ProjectAnalyzation-mt.1'].! !
